@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
+import os
 from django.conf import settings
+from django.db.models import get_app
 
 class BaseTask(object):
     """
@@ -30,7 +32,7 @@ def get_apps_under_test(test_labels, all_apps=False):
     """
     Convert test_lables for apps names
 
-    all_apps - if test_labels empty, ignore white list, 
+    all_apps - if test_labels empty, ignore white list,
     and returns all installed apps
     """
     if not test_labels:
@@ -44,3 +46,11 @@ def get_apps_under_test(test_labels, all_apps=False):
                     if app == label.split('.')[0] or app.endswith('.%s' % label.split('.')[0])]
     return apps
 
+
+def get_apps_locations(test_labels, all_apps=False):
+    """
+    Returns list of paths to tested apps
+    """
+    return [os.path.dirname(get_app(app_name.split('.')[-1]).__file__) \
+            for app_name in get_apps_under_test(test_labels, all_apps)]
+
